@@ -5,7 +5,7 @@ pytest_instafail
 
 py.test plugin to show failures instantly.
 
-:copyright: (c) 2013 by Janne Vanhala.
+:copyright: (c) 2013-2014 by Janne Vanhala.
 :license: BSD, see LICENSE for more details.
 """
 import pytest
@@ -53,7 +53,7 @@ class InstafailingTerminalReporter(TerminalReporter):
         # Show failures and errors occuring during running a test
         # instantly.
         TerminalReporter.pytest_runtest_logreport(self, report)
-        if report.failed:
+        if report.failed and not hasattr(report, 'wasxfail'):
             if self.verbosity <= 0:
                 self._tw.line()
             self.print_failure(report)
@@ -82,4 +82,5 @@ class InstafailingTerminalReporter(TerminalReporter):
                 elif report.when == "teardown":
                     msg = "ERROR at teardown of " + msg
                 self.write_sep("_", msg)
-                self._outrep_summary(report)
+                if not self.config.getvalue("usepdb"):
+                    self._outrep_summary(report)
